@@ -1,5 +1,5 @@
 #ifndef __HADDOCK__
--- $Id: Cinnamon.hs,v 1.9 2007/01/02 09:41:56 ha-tan Exp $
+-- $Id: Cinnamon.hs,v 1.11 2007/01/14 08:54:30 ha-tan Exp $
 #endif
 module Cinnamon (
   module Cinnamon.Base64,
@@ -8,6 +8,7 @@ module Cinnamon (
   module Cinnamon.Misc,
   module Cinnamon.Nkf,
   module Cinnamon.Rot13,
+  module Cinnamon.RubyString,
   module Cinnamon.Ucs
 ) where
 
@@ -17,4 +18,5 @@ import Cinnamon.Crc
 import Cinnamon.Misc
 import Cinnamon.Nkf
 import Cinnamon.Rot13
+import Cinnamon.RubyString
 import Cinnamon.Ucs
